#!/usr/bin/env python

import json
import os
import requests
from requests.auth import HTTPBasicAuth
import xml.etree.ElementTree as ET
import yaml

CONFIG_PATH = os.environ.get(
    'ZABBIX_IMPORTER_CONFIG_PATH',
    '/etc/racks/importers/jenkins.yaml')

settings = yaml.load(open(CONFIG_PATH, 'r'))

for instance in settings.get('instances', []):
    config = settings['instances'].get(instance)

    http_headers = {
        'User-agent': config.get('user_agent', 'Racks Jenkins Importer/0.1'),
    }

    jenkins_headers = http_headers.copy()
    racks_headers = http_headers.copy()

    racks_headers.update({
        'X-Auth-Application': config.get('racks_application'),
        'X-Auth-Token': config.get('racks_auth_token'),
    })

    list_racks = requests.get('%s/api/v1/object/list.json' % (
        config.get('racks_url')), headers=racks_headers)

    list_jenkins = requests.get('%s/computer/api/json' % (
        config.get('jenkins_url')), headers=jenkins_headers)

    try:
        racks_hostlist = json.loads(list_racks.text)
    except json.ValueError:
        print list_racks.text

    try:
        jenkins_hostlist = json.loads(list_jenkins.text)
    except json.ValueError:
        print list_jenkins.text

    for host in jenkins_hostlist['computer']:
        if host['displayName'] in racks_hostlist:
            nodeconfig = requests.get('%s/computer/%s/config.xml' % (
                config.get('jenkins_url'), host['displayName']),
                headers=jenkins_headers,
                auth=HTTPBasicAuth(
                    config.get('jenkins_user'), config.get('jenkins_token')))

            if nodeconfig.status_code == 200:
                _element_tree = ET.fromstring(nodeconfig.text.encode('utf-8'))
                node_labels = _element_tree.find('label').text or ''
                labels = list(set((node_labels.split(' '))))
                labels = [
                    '_'.join([config.get('label_tag'), x]) for x in labels]

                query = {
                    'name': host['displayName'],
                    'labels': json.dumps(labels),
                }

                print labels

                req = requests.post(
                    '%s/api/v1/import.json' % config.get('racks_url'),
                    headers=http_headers,
                    data=query)

                print req.text
            else:
                print '[ERROR] Status code: %s ; Body: %s' % (
                    nodeconfig.status_code, nodeconfig.text.encode('utf-8'))
