#!/usr/bin/env python

import json
import os
import re
import requests
import yaml

CONFIG_PATH = os.environ.get(
    'ZABBIX_IMPORTER_CONFIG_PATH',
    '/etc/racks/importers/puppet.yaml')

settings = yaml.load(open(CONFIG_PATH, 'r'))

for instance in settings.get('instances', []):
    config = settings['instances'].get(instance)
    RE_IGNORE_KEYS = config.get('ignore_regex')

    http_headers = {
        'User-agent': config.get('user_agent', 'Racks Puppet Importer/0.1'),
    }

    puppet_headers = http_headers.copy()
    racks_headers = http_headers.copy()
    racks_headers.update({
        'X-Auth-Application': config.get('racks_application'),
        'X-Auth-Token': config.get('racks_auth_token'),
    })

    list_req = requests.get(
        '%s/api/v1/object/list.json' % config.get('racks_url'),
        headers=racks_headers)

    try:
        hostlist = json.loads(list_req.text)
    except json.ValueError:
        print list_req.text

    for host in hostlist:
        resp = requests.get(
            '%s/puppet/node/%s?environment=production' % (
                config.get('puppet_url'), host),
            cert=(config.get('puppet_ssl_cert'), config.get('puppet_ssl_key')),
            verify=False,
            headers=puppet_headers)

        attributes = {}

        attributes['name'] = host
        try:
            facts = json.loads(resp.text)
        except ValueError:
            print resp.text
            continue
        if 'data' in facts:
            if 'parameters' in facts['data']:
                parameters = facts['data']['parameters']

                if 'virtual' in parameters:
                    if parameters['virtual'] == 'physical':
                        attributes['type'] = 'HW Server'
                    elif parameters['virtual'] == 'kvm':
                        attributes['type'] = 'KVM Virtual Machine'

                if 'location' in parameters:
                    attributes['location'] = parameters['location']

                for attribute in parameters.keys():
                    if not re.match(RE_IGNORE_KEYS, attribute):
                        attributes['attribute_%s' % attribute] = parameters[
                            attribute]

        req = requests.post(
            '%s/api/v1/import.json' % config.get('racks_url'),
            data=attributes,
            headers=racks_headers)

        print req.text
