#!/usr/bin/env python

import logging
import os
import pyzabbix
import requests
import yaml

FORMAT = '%(asctime)-15s %(levelname)s %(message)s'
logging.basicConfig(format=FORMAT)
logger = logging.getLogger(__name__)
logger.setLevel('DEBUG')

CONFIG_PATH = os.environ.get(
    'ZABBIX_IMPORTER_CONFIG_PATH',
    '/etc/racks/importers/zabbix.yaml')

settings = yaml.load(open(CONFIG_PATH, 'r'))

for instance in settings.get('instances', []):
    config = settings['instances'].get(instance)

    http_headers = {
        'User-agent': config.get('user_agent', 'Racks Zabbix Importer/0.1'),
    }

    zabbix_headers = http_headers.copy()
    racks_headers = http_headers.copy()
    racks_headers.update({
        'X-Auth-Application': config.get('racks_application'),
        'X-Auth-Token': config.get('racks_auth_token'),
    })

    api = pyzabbix.ZabbixAPI(config.get('zabbix_url'))
    api.login(
        config.get('zabbix_login'),
        config.get('zabbix_password')
    )

    groups = api.hostgroup.get(output='extend')
    hostlist = {}
    for group in groups:
        hosts = api.host.get(
            output='extend',
            groupids=group['groupid'],
            selectInventory=True)
        for host in hosts:
            fqdn = host['host']
            hostlist[fqdn] = host

            interfaces = api.hostinterface.get(
                output='extend',
                hostids=host['hostid'])

            query = {
                'name': host['host'],
                'attribute_fqdn': host['host'],
            }

            if 'inventory' in host:
                inventory = host['inventory']
                if 'hardware' in inventory:
                    query['attribute_hardware'] = host['inventory']['hardware']

                if 'software_app_a' in inventory:
                    query['attribute_puppet_manifests_version'] = inventory[
                        'software_app_a']

            if 'hostid' in host:
                query['attribute_zabbix_host_id'] = host['hostid']

            for interface in interfaces:
                # IPMI interface
                if interface['type'] == '3':
                    if interface['dns'] != '':
                        query['attribute_ipmi_host'] = interface['dns']
                    else:
                        query['attribute_ipmi_host'] = interface['ip']

            ua = requests.post(
                '%s/api/v1/import.json' % (config.get('racks_url')),
                data=query,
                headers=racks_headers
            )

            print ua.text
