from django.contrib.auth.models import User

from rest_framework import filters, status, viewsets
from rest_framework.response import Response

from inventory.models import InventoryObject
from inventory.models import InventoryObjectAttribute
from inventory.models import InventoryObjectLabel
from inventory.models import IPv4Network
from inventory.serializers import UserSerializer
from inventory.serializers import InventoryObjectAttributeSerializer
from inventory.serializers import InventoryObjectLabelSerializer
from inventory.serializers import InventoryObjectSerializer
from inventory.serializers import IPv4NetworkSerializer


class UserViewSet(viewsets.ModelViewSet):
    queryset = User.objects.all().order_by('-date_joined')
    serializer_class = UserSerializer
    filter_backends = (filters.DjangoFilterBackend,)
    filter_fields = ('username', 'email', 'inventory_objects')
    ordering_filters = ('id',)


class InventoryObjectViewSet(viewsets.ModelViewSet):
    queryset = InventoryObject.objects.all().order_by('-created')
    serializer_class = InventoryObjectSerializer
    filter_backends = (filters.DjangoFilterBackend,)
    filter_fields = (
        'name',
        'responsible',
        'location__shortname',
        'type__name')
    ordering_filters = ('id',)

    def partial_update(self, request, pk=None):
        obj = InventoryObject.objects.get(pk=pk)
        labels = request.DATA.get('labels')
        responsibles = request.DATA.get('responsible')

        if labels is not None:
            lists_output = []
            for label in labels:
                lobj, created = InventoryObjectLabel.objects.get_or_create(
                    name=label)
                lists_output.append(lobj)
            obj.label = lists_output

        if responsibles is not None:
            responsibles_output = []
            for user in User.objects.filter(username__in=responsibles):
                responsibles_output.append(user)
            obj.responsible = responsibles_output

        obj.save()

        return Response(status=status.HTTP_204_NO_CONTENT)


class IPv4NetworkViewSet(viewsets.ModelViewSet):
    queryset = IPv4Network.objects.all().order_by('-created')
    serializer_class = IPv4NetworkSerializer


class InventoryObjectAttributeViewSet(viewsets.ModelViewSet):
    queryset = InventoryObjectAttribute.objects.all().order_by('object', 'name')
    serializer_class = InventoryObjectAttributeSerializer
    filter_fields = ('object', 'name')


class InventoryObjectLabelViewSet(viewsets.ModelViewSet):
    queryset = InventoryObjectLabel.objects.all().order_by('name')
    serializer_class = InventoryObjectLabelSerializer
    filter_fields = ('inventory_objects',)
