from django.contrib.auth.models import User
from rest_framework import serializers

from inventory.models import InventoryObject
from inventory.models import InventoryObjectAttribute
from inventory.models import InventoryObjectLabel
from inventory.models import InventoryObjectLocation
from inventory.models import InventoryObjectType
from inventory.models import IPv4Network


class InventoryObjectLocationSerializer(serializers.ModelSerializer):
    class Meta:
        model = InventoryObjectLocation
        fields = ('shortname', 'fullname')


class InventoryObjectTypeSerializer(serializers.ModelSerializer):
    class Meta:
        model = InventoryObjectType
        fields = ('name',)


class UserSerializer(serializers.HyperlinkedModelSerializer):
    class Meta:
        model = User
        fields = ('id', 'url', 'username', 'email', 'groups',)


class IPv4NetworkSerializer(serializers.ModelSerializer):
    class Meta:
        model = IPv4Network
        fields = ('id', 'address', 'netmask', 'gateway',)


class InventoryObjectLabelSerializer(serializers.ModelSerializer):
    class Meta:
        model = InventoryObjectLabel


class InventoryObjectAttributeSerializer(serializers.ModelSerializer):
    class Meta:
        model = InventoryObjectAttribute
        fields = ('id', 'object', 'name', 'value')


class InventoryObjectSerializer(serializers.ModelSerializer):
    labels = serializers.SerializerMethodField('labels_list')
    location = InventoryObjectLocationSerializer(required=False)
    type = InventoryObjectTypeSerializer(many=False, required=False)
    attributes = serializers.SerializerMethodField('attributes_dict')
    responsible = serializers.SerializerMethodField('responsible_list')

    class Meta:
        model = InventoryObject
        fields = (
            'id',
            'name',
            'location',
            'type',
            'labels',
            'attributes',
            'responsible',)

    def attributes_dict(self, obj):
        attrs = {}
        for attr in obj.attributes.all():
            attrs[attr.name] = attr.value

        return attrs

    def labels_list(self, obj):
        return [x.name for x in obj.label.all()]

    def responsible_list(self, obj):
        return [x.username for x in obj.responsible.all()]
