"""
This file demonstrates writing tests using the unittest module. These will pass
when you run "manage.py test".

Replace this with more appropriate tests for your application.
"""

from django.contrib.auth.models import AnonymousUser, User
from django.test import TestCase, RequestFactory
from django.utils.http import urlquote

from inventory.views import *  # noqa


class WebUITestCase(TestCase):
    def setUp(self):
        self.factory = RequestFactory()
        self.urls = {
            '/': 'objectlist',
            '/inventory.html': 'objectlist',
            '/inventory.html?label=mylabel': 'objectlist',
            '/inventory.html?responsible=blahuser': 'objectlist',
            '/inventory.html?label=mylabel&responsible': 'objectlist',
            '/labels.html': 'labels',
            '/locations.html': 'locations',
            '/ipv4networks.html': 'ipv4networks',
            '/search.html?query=blah': 'search'
        }

    def test_authenticated_access(self):
        user = User(username='testuser')

        for url in self.urls.keys():
            request = self.factory.get(url)
            request.user = user
            response = globals()[self.urls[url]](request)

            self.assertEqual(response.status_code, 200)
            self.assertEqual(
                response['Content-Type'], 'text/html; charset=utf-8')

    def test_unautenticated_access(self):
        user = AnonymousUser()

        for url in self.urls.keys():
            request = self.factory.get(url)
            request.user = user
            response = globals()[self.urls[url]](request)

            self.assertEqual(response.status_code, 302)
            self.assertEqual(
                response['location'],
                '/account/login.html?next=%s' % urlquote(url))
